// const _ = require('lodash');
const Expo = require('expo-server-sdk');

Meteor.methods({
  'sendSms'(phoneNumber, message) {
    if (!Meteor.settings.aligo.userId) {
      throw Meteor.Error('aligo userId is undefined. check meteor setting file.', 'aligo userId is undefined. check meteor setting file.');
    }

    if (!Meteor.settings.aligo.key) {
      throw Meteor.Error('aligo key is undefined. check meteor setting file.', 'aligo key is undefined. check meteor setting file.');
    }

    if (!Meteor.settings.aligo.sender) {
      throw Meteor.Error('aligo sender is undefined. check meteor setting file.', 'aligo sender is undefined. check meteor setting file.');
    }

    const encodedMessage = encodeURIComponent(message);

    HTTP.call('GET', `https://apis.aligo.in/?userid=${Meteor.settings.aligo.userId}&key=${Meteor.settings.aligo.key}&sender=${Meteor.settings.aligo.sender}&receiver=${phoneNumber}&msg=${encodedMessage}`);
  },
  'sendRemoteNotification'(to, title, content) {
    const expo = new Expo();

    let notificationTokens = null;

    if (to == 'all') {
      const users = Meteor.users.find({
        'profile.isGettingNotificationsOn': true
      }).fetch();

      notificationTokens = _.reduce(users, (result, user) => {
        return result.concat(user.profile.notificationTokens);
      }, []);
    }
    else {
      const user = Meteor.users.findOne({
        $and: [
          {
            _id: to
          },
          {
            'profile.isGettingNotificationsOn': true
          }
        ]
      });

      notificationTokens = user.profile.notificationTokens
    }

    const messages = [];

    for (let notificationToken of notificationTokens) {
      if (!Expo.isExpoPushToken(notificationToken)) {
        continue;
      }

      messages.push({
        to: notificationToken,
        title: title,
        body: content,
        sound: 'default'
      })
    }

    const chunks = expo.chunkPushNotifications(messages);

    (async () => {
      for (let chunk of chunks) {
        await expo.sendPushNotificationsAsync(chunk);
      }
    })();
  },
  'uploadImage'(data) {
    const buffer = new Buffer(data, 'base64');

    const s3 = new AWS.S3();

    const key = `${(new Date()).getTime()}_${this.userId}`;

    s3.upload({
      ACL: Meteor.settings.aws.acl,
      Bucket: Meteor.settings.aws.imageUpload.bucket,
      Key: key,
      Body: buffer
    }, (error) => {
      if (error) {
        throw new Meteor.Error(error.message, error.message);
      }
    });

    return `${Meteor.settings.aws.imageUpload.cdn}/${key}`;
  }
});
