import React, { Component } from 'react';
import { createContainer } from 'meteor/react-meteor-data'; // eslint-disable-line
import PropTypes from 'prop-types';

import './Info.less';
import { Links } from '../../../api/links/links';

class Info extends Component {
  static propTypes = {
    areLinksReady: PropTypes.bool.isRequired,
    links: PropTypes.array.isRequired
  };

  state = {
    title: '',
    url: ''
  };

  onSubmit = (event) => {
    event.preventDefault();

    Meteor.call('links.insert', {
      title: this.state.title,
      url: this.state.url
    }, (error) => {
      if (error) {
        alert(error.reason);
        
        return;
      }

      this.setState({
        title: '',
        url: ''
      });
    });
  };

  renderLinks = () => {
    return this.props.links.map((link) => {
      return (
        <li key={link._id}>
          <a href={link.url} target="_blank">{ link.title }</a>
        </li>
      );
    });
  };

  render() {
    if (!this.props.areLinksReady) {
      return null;
    }

    return (
      <div className="info">
        <h2>Learn Meteor!</h2>
        <ul>
          <li>
            <form onSubmit={this.onSubmit}>
              <input placeholder="Title" value={this.state.title} onChange={(event) => { this.setState({ title: event.target.value }); }} />
              <input type="url" placeholder="Url" value={this.state.url} onChange={(event) => { this.setState({ url: event.target.value }); }} />
              <input type="submit" value="Add new link" onClick={this.onSubmit} />
            </form>
          </li>
          { this.renderLinks() }
        </ul>
      </div>
    );
  }
}

export default createContainer(() => {
  const linksHandle = Meteor.subscribe('links', {});

  return {
    areLinksReady: linksHandle.ready(),
    links: Links.find().fetch()
  };
}, Info);
